@@ -17,7 +17,7 @@ from typing import Any, Dict, List
 # 实盘 API地址
 from urllib.parse import urlencode
 
-from strategy_api.event.engine import EventEngine
+from strategy_api.event.engine import EventEngine, EVENT_TIMER, Event
 from strategy_api.tm_api.api.rest.rest_client import RestClient, Request, Response
 from strategy_api.tm_api.api.websocket.websocket_client import WebsocketClient
 from strategy_api.tm_api.base import BaseGateway
@@ -135,6 +135,12 @@ class OkexFutureUsdtGateway(BaseGateway):
             proxy_port,
         )
 
+        self.event_engine.unregister(EVENT_TIMER, self.trade_ws_api.ping_pong)
+        self.event_engine.register(EVENT_TIMER, self.trade_ws_api.ping_pong)
+
+        self.event_engine.unregister(EVENT_TIMER, self.market_ws_api.ping_pong)
+        self.event_engine.register(EVENT_TIMER, self.market_ws_api.ping_pong)
+
     # 订阅数据
     def subscribe(self, symbol: str, data_type: DataType, interval: Interval = None) -> None:
         new_symbol = symbol_deal(symbol, self.exchange)
@@ -543,13 +549,13 @@ class OkexRestApi(RestClient):
             path: str = "/api/v5/trade/order-algo"
 
         elif req.type == OrderType.STOP_MARKET:
-            params['slTriggerPx'] = str(req.price)  # 止损触发价
+            params['slTriggerPx'] = str(req.stop_loss_price)  # 止损触发价
             params['slOrdPx'] = '-1'  # 止损委托价,当为 -1 时。按市价止损
             params['ordType'] = "conditional"
             path: str = "/api/v5/trade/order-algo"
 
         elif req.type == OrderType.TAKE_PROFIT_MARKET:
-            params['tpTriggerPx'] = str(req.price)  # 止盈触发价
+            params['tpTriggerPx'] = str(req.stop_profit_price)  # 止盈触发价
             params['tpOrdPx'] = '-1'  # 止盈委托价, 当为-1 时，按市价止盈
             params['ordType'] = "conditional"
             path: str = "/api/v5/trade/order-algo"
@@ -627,6 +633,9 @@ class OkexWebsocketPublicApi(WebsocketClient):
         self.ticks: Dict[str, TickData] = {}
         self.bars: Dict[str, BarData] = {}
 
+        self.ping_count = 0
+        self.ping_max_num = 20
+
     def connect(
             self,
             proxy_host: str,
@@ -636,6 +645,13 @@ class OkexWebsocketPublicApi(WebsocketClient):
         self.init(PUBLIC_WEBSOCKET_HOST, proxy_host, proxy_port, 20)
         self.start()
 
+    def ping_pong(self, event: Event) -> None:
+        if self.ping_count > self.ping_max_num:
+            self.send_packet("ping")
+            self.ping_count = 0
+        else:
+            self.ping_count += 1
+
     def subscribe(self, symbol: str, interval: Interval = None) -> None:
         """订阅行情"""
         if interval:
@@ -676,22 +692,24 @@ class OkexWebsocketPublicApi(WebsocketClient):
 
     def on_connected(self) -> None:
         """连接成功回报"""
-        args = []
-        for target in self.bars:
-            symbol, interval = target.split("*")
-            d = {"channel": f"candle{interval}", "instId": symbol}
-            args.append(d)
-        for target in self.ticks:
-            d = {"channel": "tickers", "instId": target}
-            args.append(d)
-        if args:
-            req: dict = {
-                "op": "subscribe",
-                "args": args
-            }
-            self.send_packet(req)
-        print("Okex Websocket Public API连接成功")
-        pass
+        if self.ping_count > self.ping_max_num:
+            args = []
+            for target in self.bars:
+                symbol, interval = target.split("*")
+                d = {"channel": f"candle{interval}", "instId": symbol}
+                args.append(d)
+            for target in self.ticks:
+                d = {"channel": "tickers", "instId": target}
+                args.append(d)
+            if args:
+                req: dict = {
+                    "op": "subscribe",
+                    "args": args
+                }
+                self.send_packet(req)
+            print("Okex Websocket Public API连接成功, 重新订阅")
+        else:
+            print("Okex Websocket Public API连接成功, 没有重新订阅")
 
     def on_disconnected(self) -> None:
         """连接断开回报"""
@@ -700,6 +718,10 @@ class OkexWebsocketPublicApi(WebsocketClient):
 
     def on_packet(self, packet: dict) -> None:
         """推送数据回报"""
+        print(packet)
+
+        self.ping_count = 0
+
         if "event" in packet:
             event: str = packet["event"]
             if event == "subscribe":
@@ -769,6 +791,9 @@ class OkexWebsocketPrivateApi(WebsocketClient):
 
         self.reqid_order_map: Dict[str, OrderData] = {}
 
+        self.ping_count = 0
+        self.ping_max_num = 20
+
     def connect(
             self,
             key: str,
@@ -785,9 +810,20 @@ class OkexWebsocketPrivateApi(WebsocketClient):
         self.init(PRIVATE_WEBSOCKET_HOST, proxy_host, proxy_port, 20)
         self.start()
 
+    def ping_pong(self, event: Event) -> None:
+        if self.ping_count > self.ping_max_num:
+            self.send_packet("ping")
+            self.ping_count = 0
+        else:
+            self.ping_count += 1
+
     def on_connected(self) -> None:
         """连接成功回报"""
-        self.login()
+        if self.ping_count > self.ping_max_num:
+            self.login()
+            print("私有频道链接成功，重新登陆")
+        else:
+            print("私有频道链接成功，没有重新登陆")
 
     def on_disconnected(self) -> None:
         """连接断开回报"""
@@ -796,6 +832,9 @@ class OkexWebsocketPrivateApi(WebsocketClient):
 
     def on_packet(self, packet: dict) -> None:
         """推送数据回报"""
+        print(packet)
+        self.ping_count = 0
+
         if "event" in packet:
             cb_name: str = packet["event"]
         elif "op" in packet:
@@ -821,6 +860,7 @@ class OkexWebsocketPrivateApi(WebsocketClient):
     def on_login(self, packet: dict) -> None:
         """用户登录请求回报"""
         if packet["code"] == '0':
+            print("重新登陆成功，重新订阅 订单数据")
             self.subscribe_topic()
         else:
             print("Websocket Private API登录失败")
