@@ -68,6 +68,7 @@ class OrderType(Enum):
     MARKET = "MARKET"  # 市价单
     STOP_MARKET = "STOP_MARKET"  # 市价止损
     TAKE_PROFIT_MARKET = "TAKE_PROFIT_MARKET"  # 世价止盈
+    STOP_LOSS_PROFIT = "STOP_LOSS_PROFIT"  # 止盈止损
 
 
 class PositionSide(Enum):
@@ -131,9 +132,10 @@ class TickData:
     low_price: float = 0
     pre_close: float = 0
     localtime: datetime = None
-    exchange: Exchange = None # 交易所
+    exchange: Exchange = None  # 交易所
     product: Product = None
 
+
 # order 数据：当前挂单
 @dataclass
 class OrderData:
@@ -152,7 +154,7 @@ class OrderData:
     update_time: datetime = datetime.now()
     reference: str = ""
     rejected_reason: str = ""  # Order Rejected Reason
-    exchange: Exchange = None # 交易所
+    exchange: Exchange = None  # 交易所
 
     # 检查订单是否有效。
     def is_active(self) -> bool:
@@ -180,7 +182,10 @@ class OrderRequest:
     offset: Offset = Offset.NONE  # 抵消
     reference: str = ""  # 参考
     positionSide: PositionSide = PositionSide.ONEWAY
-    exchange: Exchange = None # 交易所
+    exchange: Exchange = None  # 交易所
+
+    stop_loss_price: float = 0  # 止损触发价格
+    stop_profit_price: float = 0  # 止盈触发价
 
     def create_order_data(self, orderid: str) -> OrderData:
         order: OrderData = OrderData(
@@ -232,7 +237,7 @@ class HistoryRequest:
 
 @dataclass
 class ContractData:
-    symbol: str   # 简称
+    symbol: str  # 简称
     exchange: Exchange  # 交易所
     name: str  # 全称
     product: Product  # 类型
